0.2.20 (2023-08-28)
-------------------

Smaller fixes and improvements around tags, categories and filters.

- Fixed the .readthedocs.yml #102
- Moved facet filter related logic into the facet filter classes, this is a lot cleaner #100
- Remove empty facet filter fields from filterset form #100
- Refactored the post filter classes to be more consistent #100
- Category and tags are now available for podcast episodes, too #100
- Facet counts for tags and categories are now available via the API #100
